@@ -1,7 +1,7 @@
 %%
 %% %CopyrightBegin%
 %%
-%% Copyright Ericsson AB 2010-2017. All Rights Reserved.
+%% Copyright Ericsson AB 2010-2024. All Rights Reserved.
 %%
 %% Licensed under the Apache License, Version 2.0 (the "License");
 %% you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@
 %%
 
 -module(diameter_codegen).
+-moduledoc false.
 
 %%
 %% This module generates erl/hrl files for encode/decode modules from
@@ -142,8 +143,10 @@ gen(erl, ParseD, Mod) ->
 
 erl_forms(Mod, ParseD) ->
     Forms = [[{?attribute, module, Mod},
+              {?attribute, moduledoc, false},
               {?attribute, compile, {parse_transform, diameter_exprecs}},
-              {?attribute, compile, nowarn_unused_function}],
+              {?attribute, compile, nowarn_unused_function},
+              {?attribute, dialyzer, no_return}],
              make_hrl_forms(ParseD),
              [{?attribute, export, [{name, 0},
                                     {id, 0},
